Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(502)

Unified Diff: ppapi/proxy/plugin_message_filter.h

Issue 324143002: Decouple IPC::MessageFilter from IPC::Channel (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fixing compilation errors Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ppapi/proxy/plugin_message_filter.h
diff --git a/ppapi/proxy/plugin_message_filter.h b/ppapi/proxy/plugin_message_filter.h
index 3b050895afd50fe6109dfc864a0103cc1a98383f..4018ffcc9e108bd3a8448791112155bb808ff799 100644
--- a/ppapi/proxy/plugin_message_filter.h
+++ b/ppapi/proxy/plugin_message_filter.h
@@ -41,7 +41,7 @@ class PPAPI_PROXY_EXPORT PluginMessageFilter : public IPC::MessageFilter,
virtual ~PluginMessageFilter();
// MessageFilter implementation.
- virtual void OnFilterAdded(IPC::Channel* channel) OVERRIDE;
+ virtual void OnFilterAdded(IPC::Sender* sender) OVERRIDE;
virtual void OnFilterRemoved() OVERRIDE;
virtual bool OnMessageReceived(const IPC::Message& message) OVERRIDE;
@@ -72,9 +72,9 @@ class PPAPI_PROXY_EXPORT PluginMessageFilter : public IPC::MessageFilter,
scoped_refptr<ResourceReplyThreadRegistrar> resource_reply_thread_registrar_;
// The IPC channel to the renderer. May be NULL if we're not currently
// attached as a filter.
- IPC::Channel* channel_;
+ IPC::Sender* sender_;
};
} // namespace proxy
@@ -72,9 +72,9 @@ class PPAPI_PROXY_EXPORT PluginMessageFilter : public IPC::MessageFilter,
scoped_refptr<ResourceReplyThreadRegistrar> resource_reply_thread_registrar_;
- // The IPC channel to the renderer. May be NULL if we're not currently
+ // The IPC sender to the renderer. May be NULL if we're not currently
// attached as a filter.

Powered by Google App Engine
This is Rietveld 408576698